SystemOrganization addCategory: #'Deltawerken-Core-Fields'!
SystemOrganization addCategory: #'Deltawerken-Core-Validation'!
SystemOrganization addCategory: #'Deltawerken-Core-Localization'!

Object subclass: #DEField
	instanceVariableNames: 'key accessor label info sorted reverse searchStrategy readonly validator updater inputId editInfo summarySize sortBlock columnClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEField commentStamp: 'DiegoLont 4/11/2012 13:00' prior: 0!
DEField is the root class of all fields. It has some basic functionality to store common properties, and to display those.

Instance Variables:
	key 		used for linking this field to custom actions
	accessor	used to get/set the value from the domainobject
	label		the name of this field
	info 		information that can be displayed in a mouse over.
	sorted 		indicates if one can sort on this field
	reverse	defeault search order
	searchStrategy	<ProtoObject>
	readonly	<Boolean>
	validator	<DEValidator | SEValidator>
	updater	<DEUpdater>
	inputId	<ProtoObject | PseudoContext>
	editInfo	<ProtoObject>
	summarySize	<ProtoObject>
	sortBlock	<ProtoObject>
	columnClass	<ProtoObject>!

DEField subclass: #DEBooleanField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEBooleanField class methodsFor: 'accessing' stamp: 'DiegoLont 9/4/2012 09:58'!
stringValueOf: aValue
	aValue ifNil: [ ^'' ].
	aValue
		ifTrue: [ ^'Yes' ]
		ifFalse: [ ^'No' ]! !

!DEBooleanField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:05'!
brushFor: aSubject on: canvas
	^canvas checkbox
		callback: [ :value | 
			(self trueSubject: aSubject) perform: (self trueAccessor) asMutator with: value 
		];
		value: (self value: aSubject).
! !

!DEBooleanField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:05'!
readonlyWidgetOn: canvas values: values
	| value |
	value := values at: self.
	(value notNil and: [ value or: [ self searchStrategy check not ] ]) 
		ifTrue: [ canvas text: (self class stringValueOf: value) ]
		ifFalse: [ canvas space ]! !

!DEBooleanField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:05'!
renderWidgetFor: aSubject on: canvas
	canvas checkbox
		callback: [ :value | 
			(self trueSubject: aSubject) perform: (self trueAccessor) asMutator with: value 
		];
		value: (self value: aSubject).
! !

!DEBooleanField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:05'!
renderWidgetOn: canvas values: values
	values ifNotNil: [
		canvas checkbox
			value: (values at: self);
			callback: [ :value| values at: self put: value ] ]! !

!DEBooleanField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:05'!
stringValueOf: aSubject
	^self class stringValueOf: (self value: aSubject)
! !

DEField subclass: #DEDateField
	instanceVariableNames: 'id triggerId futureDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEDateField class methodsFor: 'accessing' stamp: 'DiegoLont 5/16/2011 09:31'!
printDate: aValue
	(aValue isKindOf: Date) ifTrue: [ ^aValue yyyymmdd ].
	aValue ifNotNil: [ ^aValue greaseString ].
	^nil! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:05'!
beFutureDate
	futureDate := true! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:05'!
bePastDate
	futureDate := false! !

!DEDateField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:05'!
brushFor: aSubject on: canvas
	^canvas textInput
		value: (self class printDate: (self value: aSubject));
		yourself.! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:05'!
convertFromString: aString
	^self validator adaptedValue: aString! !

!DEDateField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:22'!
createColumn
	^ DEReportColumn new
		title: label;
		columnClass: self columnClass;
		valueBlock: [ :row | self value: row ];
		formatBlock: 
			[ :value :html | 
				value 
					ifNil: [ html text: '-' ]
					ifNotNil: [ html text: (value printFormat: #(1 2 3 $- 1 1 2)) ] ];
		yourself! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 8/28/2012 00:13'!
defaultValidator
	^DEDateValidator on: self isFutureDate! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:05'!
isFutureDate
	futureDate ifNil: [ ^true ].
	^futureDate! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:05'!
isValidValue: aValue
	aValue ifNil: [ ^false ].
	(aValue isKindOf: Date) ifTrue: [ ^self validator isValid: aValue ].
	^false! !

!DEDateField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:05'!
readonlyWidgetOn: canvas values: values
	canvas text: (self class printDate: (values at: self))! !

!DEDateField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:05'!
stringValueOf: aSubject
	^self class printDate: (self value: aSubject)! !

DEField subclass: #DEDomainField
	instanceVariableNames: 'domainClass panel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEDomainField methodsFor: 'accessing' stamp: 'DiegoLont 8/26/2012 09:45'!
domainClass
	^ domainClass! !

!DEDomainField methodsFor: 'accessing' stamp: 'DiegoLont 8/26/2012 09:45'!
domainClass: anObject
	domainClass := anObject! !

!DEDomainField methodsFor: 'rendering' stamp: 'DiegoLont 8/26/2012 09:45'!
labelFor: aSubject on: canvas
	self panel ifNil: [^super labelFor: aSubject on: canvas].
	canvas anchor
		callback: [ self show: (self value: aSubject) ];
		with: self label! !

!DEDomainField methodsFor: 'rendering' stamp: 'DiegoLont 8/26/2012 09:45'!
labelFor: aSubject readonly: aReadonly on: canvas showBlock: aBlock
	(aBlock isNil or: [ aReadonly not ]) ifTrue: [
		^super labelFor: aSubject readonly: aReadonly on: canvas showBlock: aBlock ].
	canvas anchor
		callback: [ aBlock value: (self value: aSubject) value: self ];
		with: self label! !

!DEDomainField methodsFor: 'accessing' stamp: 'DiegoLont 8/26/2012 09:45'!
panel
	^ panel! !

!DEDomainField methodsFor: 'accessing' stamp: 'DiegoLont 8/26/2012 09:45'!
panel: anObject
	panel := anObject! !

!DEDomainField methodsFor: 'navigation' stamp: 'DiegoLont 8/26/2012 09:45'!
show: aValue
	self subclassResponsibility! !

DEDomainField subclass: #DEDomainObjectField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEDomainObjectField methodsFor: 'initialization' stamp: 'DiegoLont 4/26/2011 13:33'!
initialize
	super initialize.
	"self beReadonly"! !

!DEDomainObjectField methodsFor: 'codegeneration' stamp: 'DiegoLont 5/12/2011 11:32'!
objectiveCType
	" By default every object is a string"
	^'id'! !

!DEDomainObjectField methodsFor: 'navigation' stamp: 'DiegoLont 2/3/2011 19:34'!
show: aValue
	self panel showDetails: aValue! !

!DEDomainObjectField methodsFor: 'accessing' stamp: 'DiegoLont 12/14/2012 16:32'!
stringValueOf: aSubject
	| value |
	value := self value: aSubject.
	value ifNotNil: [ ^value displayString ].
	^'nil'! !

!DEField class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:03'!
collectionFor: aSubject accessor: anAccessor
	^(aSubject perform: anAccessor) collect: [:each | aSubject perform: each]! !

!DEField class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:03'!
collectionFor: aSubject on: anAccessor
	^(aSubject perform: anAccessor) collect: [:each | aSubject perform: each]! !

!DEField class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:03'!
fields
	^#(labelField infoField)! !

!DEField class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:21'!
infoField
	^DEStringField new
		label: 'Info';
		accessor: #(#info);
		yourself! !

!DEField class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:21'!
labelField
	^DEStringField new
		label: 'Label';
		accessor: #(#label);
		yourself! !

!DEField class methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
noCollectionTitle
	^'Fields'! !

!DEField class methodsFor: 'accessing' stamp: 'StephanEggermont 9/3/2012 22:37'!
noTitle
	| retVal |
	self = DEField ifTrue: [ ^'Field' ].
	retVal := self name.
	retVal size > 8 ifTrue: [ ^retVal copyFrom: 3 to: (retVal size - 5) ].
	^super noTitle! !

!DEField class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:03'!
on: aKey
	^self basicNew
		initialize: aKey;
		yourself! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
abbreviationOf: aSubject size: aSize
	^((self stringValueOf: aSubject) copyFrom: 1 to: aSize), '...'! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
accessor
	accessor ifNil: [ ^#() ].
	^ accessor! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
accessor: anObject
	accessor := anObject! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
actionOn: canvas values: values! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 3/12/2012 14:52'!
addToAccessor: anArray
	self accessor: (anArray asOrderedCollection copy
		addAll: self accessor;
		yourself)! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 2/7/2012 14:11'!
asString: aSubject
	| retVal |
	retVal := self value: aSubject.
	(self isValidValue: retVal) ifFalse: [ ^'' ].
	^retVal asString.! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
beReadonly
	readonly := true! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 2/22/2012 11:13'!
beRequired
	self validator ifNil: [ 
		validator := DEStringValidator new
			errorMessage: 'automatic check';
			yourself ].
	self validator beRequired! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
beWritable
	readonly := false! !

!DEField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:03'!
brushFor: aSubject on: canvas
	(self hasValueFor: aSubject)
		ifTrue: [ 
			canvas text: (self stringValueOf: aSubject).
			^nil ]
		ifFalse: [ ^canvas space ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
columnClass
	columnClass ifNil: [ ^'table-column' ].
	^columnClass! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
columnClass: anObject
	columnClass := anObject! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
convertFromString: aString
	^aString! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 12/22/2011 16:16'!
createColumn
	sortBlock ifNotNil: [
		^DEReportColumn new
			columnClass: self columnClass;
			title: self label;
			valueBlock: [ :row | row ];
			formatBlock: [ :subject :html | html text: (self summaryOf: subject) ];
			sortBlock: self sortBlock;
			yourself
	].
	^DEReportColumn new
		title: self label;
		columnClass: self columnClass;
		valueBlock: [ :row | self summaryOf: row ];
		yourself
! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
defaultAction
	^nil! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 2/6/2012 15:34'!
defaultSearchStrategy
	^DESearchStrategy defaultStrategy! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
defaultSummarySize
	^60! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
defaultValidator
	^nil! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
divContentFor: aSubject on: canvas action: aAction readonly: aReadonly 
	canvas span
		class: 'fieldLabel';
		with: 
			[ self 
				labelFor: aSubject
				readonly: aReadonly
				on: canvas ].
	canvas span
		class: 'fieldInfo';
		with: 
			[ self 
				infoFor: aSubject
				on: canvas
				readonly: (self readonly or: [ aReadonly ]) ].
	canvas span
		class: 'fieldWidget';
		class: self requiredClass;
		with: 
			[ self 
				widgetFor: aSubject
				on: canvas
				readonly: (self readonly or: [ aReadonly ]) ].
	canvas span
		class: 'fieldAction';
		with: 
			[ aAction ifNotNil: 
				[ aAction 
					renderFor: aSubject
					on: canvas ] ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
editInfo
	editInfo ifNil: [
		info 
			ifNil: [ validator ifNil: [ ^nil ].
				^validator info ].
		^info ].
	^editInfo! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
editInfo: aString
	editInfo := aString! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
fullUpdate
	self validator ifNil: [ ^false ].
	^self validator fullUpdate! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
hasValueFor: aSubject
	^(self value: aSubject) notNil.
! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
info
	^info
			! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
info: anObject
	info := anObject! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
infoFor: values
	^self info! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
infoFor: aSubject on: canvas readonly: aBoolean
	self infoOn: canvas readonly: aBoolean! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
infoOn: canvas readonly: aBoolean
	aBoolean
		ifTrue: [ self infoOn: canvas text: self info ]
		ifFalse: [ self infoOn: canvas text: self editInfo ]! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:19'!
infoOn: canvas text: aString
	aString
		ifNil:[ canvas space ]
		ifNotNil:[
			canvas image
				altText: 'i';
				title: aString;
				url: DEFileLibrary / #infoPng ]! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
infoOn: canvas values: values
	self infoOn: canvas text: (self infoFor: values)! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
initialize: aKey
	self initialize.
	key := aKey! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
inputId
	^ inputId! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
inputId: anObject
	inputId := anObject! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isCollectionField
	^false! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isComposite
	^false! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isList
	^false! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isListField
	^false! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isMulti: aValue
	^false! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isSorted
	sorted ifNil: [ ^false ].
	^sorted.! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isValid: aSubject
	self validator ifNotNil: [ ^self validator isValid: (self value: aSubject) subject: aSubject ].
	^true! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isValidError: aSubject
	self validator ifNotNil: [ 
		self validator validate.
		^self validator isValidError: (self value: aSubject) subject: aSubject ].
	^#()! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isValidSearchValue: aValue
	^self isValidValue: aValue
! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
isValidValue: aValue
	aValue ifNil: [ ^false ].
	^true! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 16:39'!
key
	key ifNil: [ ^Array with: self accessor with: self class ].
	^ key! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
key: anObject
	key := anObject! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
label
	^ label! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
label: anObject
	label := anObject! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
labelFor: aSubject on: canvas
	self labelOn: canvas! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
labelFor: aSubject readonly: aReadonly on: canvas
	self labelOn: canvas readonly: aReadonly! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
labelFor: aSubject readonly: aReadonly on: canvas showBlock: aBlock
	self labelOn: canvas readonly: aReadonly! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
labelOn: canvas
	canvas text: (self label)! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
labelOn: canvas readonly: aReadonly
	self labelOn: canvas! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
match: aSubject with: anotherSubject
	" We only match if both subjects have a value for this field "
	(self hasValueFor: aSubject) ifFalse: [ ^0 ].
	(self hasValueFor: anotherSubject) ifFalse: [ ^0 ].
	(self valueFor: aSubject) = (self valueFor: anotherSubject) ifTrue: [ ^1 ].
	^0
	! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
readonly
	readonly ifNil: [ ^false ].
	^readonly! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
readonlyWidgetFor: aSubject on: canvas
	(self hasValueFor: aSubject)
		ifTrue: [ canvas text: (self stringValueOf: aSubject) ]
		ifFalse: [ self renderEmptyValueOn: canvas ]! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
readonlyWidgetFor: aSubject on: canvas panel: aPanel
	self readonlyWidgetFor: aSubject on: canvas! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
readonlyWidgetOn: canvas values: values
	canvas text: (values at: self)! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
renderEmptyValueOn: canvas
	canvas space! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
renderErrorMessageFor: aSubject on: canvas
	self validator ifNotNil: [
		canvas span
			class: 'errorMessage';
			with: (self validator isValidError: (self value: aSubject) subject: aSubject) ]! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 2/6/2012 15:41'!
renderReadonlyTableRowOn: canvas values: values
	canvas tableRow: [
		canvas tableData: [	self labelOn: canvas ].
		canvas tableData: [	self infoOn: canvas values: values ].
		canvas tableData: [	self readonlyWidgetOn: canvas values: values ] ]! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 2/3/2012 13:50'!
renderTableRowContentOn: canvas values: values action: anAction
	canvas tableData: [	self labelOn: canvas ].
	canvas tableData: [	self infoOn: canvas values: values ].
	canvas tableData: [	self renderWidgetOn: canvas values: values ].
	canvas tableData: [ anAction ifNotNil: [ anAction renderOn: canvas ] ]! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 2/3/2012 13:49'!
renderTableRowOn: canvas values: values action: anAction
	anAction 
		ifNil: [
			canvas tableRow: [
				self renderTableRowContentOn: canvas values: values action: anAction ] ]
		ifNotNil: [
			anAction renderBlock: [ :html |
				self renderTableRowContentOn: html values: values action: anAction ].
			canvas tableRow
				id: (anAction ensureFieldId: canvas);
				with: [ self renderTableRowContentOn: canvas values: values action: anAction ] ]! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 8/22/2011 10:11'!
renderUpdateWidgetOn: canvas for: aSubject script: aScript triggerId: aTriggerId
	| brush withBlock |
	brush := (self brushFor: aSubject on: canvas)
		id: aTriggerId;
		onChange: aScript;
		yourself.
	withBlock := self withBlockFor: aSubject on: canvas.
	withBlock ifNotNil: [ brush with: withBlock ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
required
	self validator ifNil: [ ^false ].
	^self validator required! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
requiredClass
	validator ifNil: [ ^ '' ].
	validator required ifFalse: [ ^ '' ].
	^ 'required'! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
reverse
	reverse ifNil: [ ^false ].
	^reverse! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
reverse: anObject
	reverse := anObject! !

!DEField methodsFor: 'navigation' stamp: 'StephanEggermont 5/2/2011 15:03'!
save: aValue in: aDomainObject
	(self trueSubject: aDomainObject) perform: (self trueAccessor asMutator) with: aValue! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 2/6/2012 15:31'!
searchStrategy
	^ searchStrategy ifNil: [ searchStrategy := self defaultSearchStrategy ]! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 8/22/2011 22:03'!
serializationFor: aSubject script: aScript
	^aScript! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
setValue: aValue of: aSubject
	(self trueSubject: aSubject) perform: (self trueAccessor) asMutator with: aValue! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 2/14/2012 14:57'!
simpleWidgetFor: aSubject on: canvas
	| brush withBlock |
	brush := self brushFor: aSubject on: canvas.
	withBlock := self withBlockFor: aSubject on: canvas.
	withBlock ifNotNil: [ brush with: withBlock ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
sortBlock
	^ sortBlock! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
sortBlock: anObject
	sortBlock := anObject! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
sorted
	^ sorted.! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
sorted: anObject
	sorted := anObject! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
stringValueOf: aSubject
	^(self value: aSubject) asString! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
summaryOf: aSubject
	^self summaryOf: aSubject size: self summarySize! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
summaryOf: aSubject size: aSize
	| retVal |
	retVal := self stringValueOf: aSubject.
	retVal size > aSize ifTrue: [ retVal := self abbreviationOf: aSubject size: aSize ].
	^retVal! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
summarySize
	summarySize ifNil: [ ^self defaultSummarySize ].
	^summarySize! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
summarySize: anInteger
	summarySize := anInteger! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
switchValue: aValue
	^aValue! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:41'!
trueAccessor
	accessor isSymbol ifTrue: [ ^accessor ].
	^accessor last.
	! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:40'!
trueSubject: aSubject
	| value |
	accessor isSymbol ifTrue: [ ^aSubject ].
	value := aSubject.
	1 to: accessor size - 1 do: [ :index | value := value perform: (accessor at: index) ].
	^value.
	! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
updater
	^ updater! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
updater: anObject
	updater := anObject! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 8/21/2011 15:18'!
updaterWidgetFor: aSubject on: canvas
	updater widgetFor: aSubject field: self on: canvas! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
validate
	self validator ifNotNil: [ self validator validate ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
validate: aSubject
	self validator ifNotNil: [ validator validate ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
validator
	^ validator ifNil: [ validator := self defaultValidator ]! !

!DEField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:03'!
validator: anObject
	validator := anObject! !

!DEField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:39'!
value: aSubject
	| value |
	aSubject ifNil: [ ^nil ].
	value := aSubject.
	accessor isSymbol
		ifTrue: [ value := value perform: accessor ]
		ifFalse: [ accessor do: [ :each |	value := value perform: each ] ].
	^value.! !

!DEField methodsFor: 'rendering' stamp: 'DiegoLont 2/14/2012 14:58'!
widgetFor: aSubject on: canvas
	self updater ifNil: [
		self validator
			ifNil: [ ^self simpleWidgetFor: aSubject on: canvas ]
			ifNotNil: [ updater := DEUpdater new ] ].
	self updaterWidgetFor: aSubject on: canvas! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
widgetFor: aSubject on: canvas readonly: aBoolean 
	aBoolean
		ifTrue: [ self readonlyWidgetFor: aSubject on: canvas ]
		ifFalse: [ self widgetFor: aSubject on: canvas ]! !

!DEField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:03'!
widgetFor: aSubject on: canvas readonly: aBoolean panel: aPanel
	aBoolean
		ifTrue: [ self readonlyWidgetFor: aSubject on: canvas panel: aPanel ]
		ifFalse: [ self widgetFor: aSubject on: canvas ]! !

!DEField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:03'!
withBlockFor: aSubject on: canvas
	^nil! !

DEField subclass: #DEMemoField
	instanceVariableNames: 'rows columns labelInfo matcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEMemoField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:06'!
brushFor: aSubject on: canvas
	^canvas textArea
		on: (self trueAccessor) of: (self trueSubject: aSubject);
		columns: self columns;
		rows: self rows! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
columns
	columns ifNil: [ ^40 ].
	^ columns ! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
columns: anObject
	columns := anObject! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
hasValueFor: aSubject
	| value |
	value := self value: aSubject.
	^value notNil and: [ value notEmpty ]
! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
isValidValue: aValue
	aValue ifNil: [ ^false. ].
	aValue isEmpty ifTrue: [ ^false ].
	^true! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
labelInfo
	^ labelInfo! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
labelInfo: anObject
	labelInfo := anObject! !

!DEMemoField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:06'!
labelOn: canvas readonly: aReadonly
	super labelOn: canvas readonly: aReadonly.
	aReadonly ifFalse: [ self labelInfo ifNotNil: [ canvas span
			class: 'label-info';
			with: '(', self labelInfo, ')' ] ].! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
match: aSubject with: anotherSubject
	" We only match if both subjects have a value for this field "
	self matcher ifNotNil: [ ^self matcher match: (self value: aSubject) with: (self value: anotherSubject) ].
	^super match: aSubject with: anotherSubject! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
matcher
	^ matcher! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
matcher: anObject
	matcher := anObject! !

!DEMemoField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:06'!
readonlyWidgetFor: aSubject on: canvas
	(self hasValueFor: aSubject)
		ifTrue: [	(self value: aSubject) lines 
				do: [ :line| canvas text: line ] separatedBy: [ canvas break ] ]
		ifFalse: [ canvas space ]! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
rows
	rows ifNil: [ ^4 ].
	^ rows! !

!DEMemoField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:06'!
rows: anObject
	rows := anObject! !

DEField subclass: #DESelectField
	instanceVariableNames: 'list labels listObject radioGroup'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

DESelectField subclass: #DEConditionalField
	instanceVariableNames: 'fieldLists'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:30'!
addFields: aList for: aKey
	self fieldLists at: aKey put: aList! !

!DEConditionalField methodsFor: 'updating' stamp: 'DiegoLont 9/26/2012 16:56'!
compositeIdOn: canvas  updateBlock: aBlock 
	self updater ifNil: [ self updater: DEUpdater new ].
	self updater id ifNil: [ 
		self updater id: canvas nextId.
		self updater updateBlock: aBlock ].
	^self updater id! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 3/24/2011 15:04'!
fieldListFor: aSubject 
	^ self fieldLists 
		at: (self value: aSubject)
		ifAbsent: [ nil ]! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DEL 4/27/2010 14:35'!
fieldLists
	^fieldLists ifNil: [ fieldLists := Dictionary new ]! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:28'!
fieldsFor: aSubject 
	^self fieldLists 
		at: (self value: aSubject)
		ifAbsent: [ #() ]! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 3/24/2011 15:00'!
isComposite
	^true! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:29'!
isValid: aSubject 
	(super isValid: aSubject) ifFalse: [ ^ false ].
	super validate: aSubject.
	(self fieldsFor: aSubject) do: [ :each | (each isValid: aSubject) ifFalse: [ ^false ] ].
	^ true! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:38'!
listValues
	^self fieldLists keys! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:38'!
listValues: aSubject
	^self fieldLists keys! !

!DEConditionalField methodsFor: 'accessing' stamp: 'DiegoLont 9/26/2012 15:29'!
validate: aSubject 
	super validate: aSubject.
	(self fieldsFor: aSubject) do: [ :each | each validate: aSubject ]! !

DESelectField subclass: #DEMultiSelectField
	instanceVariableNames: 'listSize allValue noneValue'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
abbreviationOf: aSubject size: aSize
	| temp end start index valueList |
	temp := self stringValueOf: aSubject.
	(temp size < aSize) ifTrue: [ ^temp ].
	valueList := self value: aSubject.
	(valueList size < 3) ifTrue: [ ^super abbreviationOf: aSubject size: aSize ].
	start := valueList first asString.
	temp := start.
	end := ', ..., ', valueList last asString, ' (', valueList size asString, ')'.
	index := 2.
	[ temp size + end size < aSize ] whileTrue: [
		start := temp.
		temp := start, ', ', (valueList at: index) asString.
		index := index + 1 ].
	^start, end! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
allValue
	^allValue! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
allValue: aString
	allValue := aString! !

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
editInfo
	editInfo ifNil: [ ^self info ].
	^editInfo! !

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
find: aText in: aSubject
	(self value: aSubject) do: [ :each |
		(self searchStrategy find: aText in: (self elemStringValueOf: each)) ifTrue: [ ^true ]
	].
	^false! !

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
hasValueFor: aSubject
	| value |
	value := self value: aSubject.
	^value notNil and: [ value notEmpty ]
! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
infoOn: canvas readonly: aBoolean
	aBoolean
		ifTrue: [ self infoOn: canvas text: self info ]
		ifFalse: [ self infoOn: canvas text: self editInfo ]
! !

!DEMultiSelectField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:07'!
listBrushOn: canvas
	^canvas multiSelect
		size: self listSize;
		yourself! !

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
listSize
	listSize ifNil: [ ^4 ].
	^listSize! !

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
listSize: anObject
	listSize := anObject! !

!DEMultiSelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
match: aSubject with: anotherSubject
	|collection1 collection2|
	collection1 := self value: aSubject.
	collection1 ifEmpty: [	^0	].
	collection2 := self value: anotherSubject.
	collection2 ifEmpty: [	^0	].		
	(collection1 intersection: collection2) ifNotEmpty: [	^1 ].
	^0.! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
noneValue
	^noneValue! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
noneValue: aString
	noneValue := aString! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
renderEmptyValueOn: canvas
	self noneValue 
		ifNil: [ canvas space ]
		ifNotNil: [ canvas render: self noneValue ]! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
stringValueOf: aSubject
	| selected |
	selected := self value: aSubject.
	(selected size = 0) ifTrue: [ ^self noneValue ].
	(selected size = (self listValues: aSubject) size) ifTrue: [ self allValue ifNotNil: [ ^self allValue ] ].
	^String streamContents: [ :s |
		selected 
			do: [ :each | s nextPutAll: (self elemStringValueOf: each) ]
			separatedBy: [ s nextPutAll: ', ' ] ]! !

!DEMultiSelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
useRadioGroupFor: aSubject
	^false! !

!DESelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
alwayRadioGroup
	radioGroup := true! !

!DESelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
alwaysListbox
	radioGroup := false! !

!DESelectField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:07'!
brushFor: aSubject on: canvas
	(self useRadioGroupFor: aSubject)
		ifTrue: [ ^self radioBrushFor: aSubject on: canvas ]
		ifFalse: [ ^self listBrushFor: aSubject on: canvas ]
! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
elemStringValueOf: aElem
	labels ifNil: [
		^aElem asString.
	] ifNotNil: [
		^labels value: aElem
	]! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
isMulti: aValue
	^aValue isKindOf: OrderedCollection
! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
isValidValue: aValue
	aValue ifNil: [ ^false. ].
	aValue isEmpty ifTrue: [ ^false ].
	^true! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
labels
	^ labels! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
labels: anObject
	labels := anObject! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
list
	^ list! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
list: anObject
	list := anObject.
	listObject := nil! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
list: anObject of: aListObject
	list := anObject.
	listObject := aListObject.! !

!DESelectField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:07'!
listBrushFor: aSubject on: canvas
	| brush |
	brush := (self listBrushOn: canvas)
		on: (self trueAccessor) of: (self trueSubject: aSubject);
		list: (self listValues: aSubject).
	labels ifNotNil: [ brush labels: labels ].
	^brush! !

!DESelectField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:07'!
listBrushOn: canvas
	^canvas select! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
listObject
	^listObject
! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
listSize
	^4! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
listValues
	"TODO: optie waarbij geen listobject is gegeven"
	^(listObject perform: (self list)).
! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
listValues: aSubject
	listObject ifNil: [
		^(aSubject perform: (self list)).
	] ifNotNil: [
		^(self listObject perform: (self list)).
	].
! !

!DESelectField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:07'!
radioBrushFor: aSubject on: canvas
	| group |
	group := canvas radioGroup.
	(self listValues: aSubject) do: [ :value |
		| brush |
		brush := canvas radioButton.
		(self value: aSubject) = value ifTrue: [ brush selected: true ].
		brush
			group: group;
			callback: [ (self trueSubject: aSubject) perform: self trueAccessor asMutator with: value ];
			submitOnClick.
		labels
			ifNil: [ brush with: value ]
			ifNotNil: [ brush with: (labels value: value) ]
	].
	^group! !

!DESelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
readonlyWidgetOn: canvas values: values
	canvas text: (self textValueFor: (values at: self))! !

!DESelectField methodsFor: 'rendering' stamp: 'DiegoLont 9/26/2012 15:53'!
renderUpdateWidgetOn: canvas for: aSubject script: aScript triggerId: aTriggerId
	(self useRadioGroupFor: aSubject)
		ifTrue: [
			canvas span
				id: aTriggerId;
				with: [		
					canvas radioGroup
						callback: [ :value | 
							(self trueSubject: aSubject) perform: self trueAccessor asMutator with: value ];
						selected: (self value: aSubject);
						with: [ :group |
							(self listValues: aSubject) do: [ :value |
								|  brush |
								brush := canvas radioButton
									group: group;
									value: value;
									onChange: aScript;
									yourself.
								self labels
									ifNil: [ brush with: value ]
									ifNotNil: [ brush with: (self labels value: value) ] ]	 ] ] ]
	ifFalse: [ super renderUpdateWidgetOn: canvas for: aSubject script: aScript triggerId: aTriggerId ]! !

!DESelectField methodsFor: 'rendering' stamp: 'DiegoLont 8/22/2011 22:05'!
serializationFor: aSubject script: aScript
	(self useRadioGroupFor: aSubject) ifTrue: [ ^(aScript find: ':input') ].
	^aScript! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
stringValueOf: aSubject
	^self elemStringValueOf: (self value: aSubject)
! !

!DESelectField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:07'!
switchValue: aValue
	(self isMulti: aValue)
		ifTrue: [ 
			aValue ifEmpty: [ ^nil ].
			^aValue first ].
	^OrderedCollection with: aValue! !

!DESelectField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:07'!
textValueFor: aValue
	(self isMulti: aValue)
		ifTrue: [ ^String streamContents: [ :s |
				aValue do: [ :each | s nextPutAll: each ] separatedBy: [ s nextPutAll: ', ' ] ] ]
		ifFalse: [ ^aValue ]! !

!DESelectField methodsFor: 'rendering' stamp: 'DiegoLont 8/22/2011 22:06'!
useRadioGroupFor: aSubject
	radioGroup 
		ifNil: [ ^(self listValues: aSubject) size < 5 ].
	^radioGroup! !

DEField subclass: #DEStringField
	instanceVariableNames: 'fieldSize tabIndex'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

DEStringField subclass: #DEEmailField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEEmailField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:30'!
createColumn
	^DEReportColumn new
		title: label;
		columnClass: self columnClass;
		valueBlock: [ :anObject :html | self readonlyWidgetFor: anObject on: html ];
		yourself! !

!DEEmailField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:09'!
readonlyWidgetFor: aSubject on: canvas
	(self hasValueFor: aSubject)
		ifTrue: [ canvas anchor
				url: 'mailto:', (self stringValueOf: aSubject);
				with: (self stringValueOf: aSubject) ]
		ifFalse: [ canvas space ]! !

DEStringField subclass: #DENumberField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

DENumberField subclass: #DEMoneyField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEMoneyField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:09'!
currencyHtml
	^'&euro;'! !

!DEMoneyField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:09'!
readonlyWidgetFor: aSubject on: canvas
	(self hasValueFor: aSubject)
		ifTrue: [
			canvas
				html: self currencyHtml;
				space;
				text: (self stringValueOf: aSubject) ]
		ifFalse: [ canvas space ]! !

!DEMoneyField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:09'!
stringValueOf: aSubject
	^(self value: aSubject) printShowingDecimalPlaces: 2! !

!DENumberField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:10'!
hasValueFor: aSubject
	^(self value: aSubject) notNil.
! !

!DENumberField methodsFor: 'initialization' stamp: 'StephanEggermont 5/2/2011 15:31'!
initialize
	super initialize.
	self validator: DENumberValidator new! !

DEStringField subclass: #DEPasswordField
	instanceVariableNames: 'required'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

!DEPasswordField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:10'!
brushOn: canvas
	^canvas passwordInput! !

!DEPasswordField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:31'!
defaultValidator
	^DEStringValidator new
		required: self required;
		errorMessage: 'Password cannot be empty';
		yourself! !

!DEPasswordField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:10'!
required
	required ifNil: [ ^true ].
	^ required! !

!DEPasswordField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:10'!
required: anObject
	required := anObject! !

!DEPasswordField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:10'!
stringValueOf: aSubject
	^'********'! !

!DEStringField methodsFor: 'tags' stamp: 'DiegoLont 2/7/2012 13:31'!
brushFor: aSubject on: canvas
	| retVal |
	retVal := (self brushOn: canvas)
		value: (self value: aSubject);
		callback: [ :value| self postValue: value subject: aSubject ];
		yourself.
	self fieldSize
		ifNotNil: [ retVal size: self fieldSize ].
	self tabIndex ifNotNil: [ retVal tabIndex: self tabIndex ].
	^retVal! !

!DEStringField methodsFor: 'tags' stamp: 'StephanEggermont 5/2/2011 15:08'!
brushOn: canvas
	^canvas textInput! !

!DEStringField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:08'!
fieldSize
	^ fieldSize! !

!DEStringField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:08'!
fieldSize: anObject
	fieldSize := anObject! !

!DEStringField methodsFor: 'accessing' stamp: 'DiegoLont 2/6/2012 15:31'!
find: aValue in: aSubject
	^self searchStrategy find: aValue in: (self asString: aSubject).! !

!DEStringField methodsFor: 'rendering' stamp: 'DiegoLont 2/27/2012 12:13'!
hasValueFor: aSubject
	| value |
	value := self value: aSubject.
	^value notNil and: [ value notEmpty ]
! !

!DEStringField methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 15:08'!
isValidValue: aValue
	aValue ifNil: [ ^false. ].
	aValue isEmpty ifTrue: [ ^false ].
	^true! !

!DEStringField methodsFor: 'accessing' stamp: 'DiegoLont 5/16/2011 09:45'!
postValue: aValue subject: aSubject
	validator 
		ifNil: [ (self trueSubject: aSubject) perform: self trueAccessor asMutator with: aValue ]
		ifNotNil: [ (self trueSubject: aSubject) perform: self trueAccessor asMutator with: (validator format: aValue) ]! !

!DEStringField methodsFor: 'rendering' stamp: 'DiegoLont 2/3/2012 13:52'!
renderWidgetOn: canvas values: values
	values ifNotNil: [
		(self brushOn: canvas)
			value: (values at: self);
			callback: [ :value| values at: self put: value ] ]! !

!DEStringField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:08'!
tabIndex
	^ tabIndex! !

!DEStringField methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:08'!
tabIndex: anObject
	tabIndex := anObject! !

Object subclass: #DELocale
	instanceVariableNames: ''
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Deltawerken-Core-Localization'!

Object subclass: #DESearchStrategy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Fields'!

DESearchStrategy class
	instanceVariableNames: 'defaultStrategy'!

DESearchStrategy class
	instanceVariableNames: 'defaultStrategy'!

!DESearchStrategy class methodsFor: 'accessing' stamp: 'DiegoLont 2/6/2012 15:34'!
defaultStrategy
	^defaultStrategy ifNil: [ defaultStrategy := self new ]! !

!DESearchStrategy methodsFor: 'accessing' stamp: 'DiegoLont 2/7/2012 14:13'!
find: aText in: aString
	^(aString findString: aText startingAt: 1 caseSensitive: false) > 0.! !

Object subclass: #DEUpdater
	instanceVariableNames: 'id updateBlock fieldSymbol triggerId'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Validation'!

!DEUpdater methodsFor: 'rendering' stamp: 'DiegoLont 8/22/2011 22:04'!
createUpdaterOn: canvas field: aField subject: aSubject id: anId
	^((canvas jQuery id: anId) load
		serialize: (aField serializationFor: aSubject script: (canvas jQuery id: triggerId)))
			html: [:s | self onChange: s field: aField subject: aSubject id: anId ]! !

!DEUpdater methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:50'!
fieldSymbol
	^ fieldSymbol! !

!DEUpdater methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:50'!
fieldSymbol: aSymbol
	fieldSymbol := aSymbol! !

!DEUpdater methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:50'!
id
	^ id! !

!DEUpdater methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:50'!
id: aString
	id := aString! !

!DEUpdater methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 14:50'!
idWidgetFor: aSubject field: aField on: canvas
	aField renderErrorMessageFor: aSubject on: canvas.
! !

!DEUpdater methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 14:50'!
idWidgetFor: aSubject field: aField on: canvas updaterId: anUpdaterId 
	self 
		widgetOnlyFor: aSubject
		field: aField
		on: canvas
		updaterId: anUpdaterId.
	self 
		renderErrorMessageFor: aSubject
		field: aField
		on: canvas! !

!DEUpdater methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 14:50'!
onChange: canvas field: aField subject: aSubject id: anId
	aField validate.
	self updateBlock 
		ifNil: [ 
			aField fullUpdate
				ifTrue: [ self idWidgetFor: aSubject field: aField on: canvas updaterId: anId ]
				ifFalse: [ self idWidgetFor: aSubject field: aField on: canvas ] ]
		ifNotNil: [ self updateBlock value: canvas ]! !

!DEUpdater methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 14:50'!
renderErrorMessageFor: aSubject field: aField on: canvas 
	aField 
		renderErrorMessageFor: aSubject
		on: canvas! !

!DEUpdater methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 14:50'!
update: canvas
	updateBlock ifNotNil: [ updateBlock value: canvas ]! !

!DEUpdater methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:50'!
updateBlock
	^ updateBlock! !

!DEUpdater methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:50'!
updateBlock: aBlock
	updateBlock := aBlock! !

!DEUpdater methodsFor: 'rendering' stamp: 'StephanEggermont 5/2/2011 14:50'!
widgetFor: aSubject field: aField on: canvas
	| updaterId |
	id 
		ifNil: [ updaterId := canvas nextId ]
		ifNotNil: [ updaterId := id ].
	aField fullUpdate
		ifTrue: [ id
			ifNil: [
				canvas span
					id: updaterId;
					with: [ 
						self idWidgetFor: aSubject field: aField on: canvas updaterId: updaterId ] ]
			ifNotNil: [ self idWidgetFor: aSubject field: aField on: canvas updaterId: updaterId ] ]
		ifFalse: [
			self widgetOnlyFor: aSubject field: aField on: canvas updaterId: updaterId.
			id
				ifNil: [
					canvas span
						id: updaterId;
						with: [ self renderErrorMessageFor: aSubject field: aField on: canvas ] ]
				ifNotNil: [ self renderErrorMessageFor: aSubject field: aField on: canvas ] ]! !

!DEUpdater methodsFor: 'rendering' stamp: 'DiegoLont 8/22/2011 10:11'!
widgetOnlyFor: aSubject field: aField on: canvas updaterId: anUpdaterId
	aField inputId 
		ifNil: [ triggerId := canvas nextId ]
		ifNotNil: [ triggerId := aField inputId ].
	aField renderUpdateWidgetOn: canvas
		for: aSubject
		script: (self createUpdaterOn: canvas field: aField subject: aSubject id: anUpdaterId)
		triggerId: triggerId! !

Object subclass: #DEValidator
	instanceVariableNames: 'validated required'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Validation'!

DEValidator subclass: #DECustomValidator
	instanceVariableNames: 'validateBlock formatBlock errorBlock invalidBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Validation'!

!DECustomValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
errorBlock
	^ errorBlock! !

!DECustomValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
errorBlock: anObject
	errorBlock := anObject! !

!DECustomValidator methodsFor: 'validating' stamp: 'StephanEggermont 5/2/2011 14:51'!
errorMessageFor: aValue 
	^self errorMessageFor: aValue subject: nil! !

!DECustomValidator methodsFor: 'validating' stamp: 'StephanEggermont 5/2/2011 14:51'!
errorMessageFor: aValue subject: aSubject
	errorBlock ifNil: [ ^'No errormessage available' ].
	errorBlock numArgs = 1 ifTrue: [	^ errorBlock value: aValue ].
	errorBlock numArgs = 2 ifTrue: [	^ errorBlock value: aSubject value: aValue ]
! !

!DECustomValidator methodsFor: 'validating' stamp: 'StephanEggermont 5/2/2011 14:51'!
format: aValue
	formatBlock ifNil: [ ^super format: aValue ].
	^formatBlock value: aValue! !

!DECustomValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
formatBlock
	^ formatBlock! !

!DECustomValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
formatBlock: anObject
	formatBlock := anObject! !

!DECustomValidator methodsFor: 'validating' stamp: 'StephanEggermont 5/2/2011 14:51'!
isValid: aValue
	^self isValid: aValue subject: nil! !

!DECustomValidator methodsFor: 'validating' stamp: 'StephanEggermont 5/2/2011 14:51'!
isValid: aValue subject: aSubject
	validateBlock ifNil: [ ^super isValid: aValue subject: aSubject ].
	validateBlock numArgs = 1 ifTrue: [ ^validateBlock value: aValue ].
	validateBlock numArgs = 2 ifTrue: [ ^validateBlock value: aSubject value: aValue ].
	^super isValid: aValue subject: aSubject! !

!DECustomValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
validateBlock
	^ validateBlock! !

!DECustomValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
validateBlock: anObject
	validateBlock := anObject! !

DEValidator subclass: #DEDateValidator
	instanceVariableNames: 'futureDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Validation'!

!DEDateValidator class methodsFor: 'instance creation' stamp: 'StephanEggermont 5/2/2011 15:23'!
on: aBoolean
	^self new
		futureDate: aBoolean;
		yourself! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
adaptedValue: aValue
	| formatString parts |
	(self isValid: aValue) ifFalse: [ ^aValue ].
	formatString := self format: aValue.
	formatString size < 8 ifTrue: [ ^aValue ].
	parts := formatString findTokens: ':-/.'.
	^Date year: (parts at: 3) asInteger month: (parts second) asInteger day: (parts first) asInteger! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 8/28/2012 00:12'!
errorMessageFor: aValue
	|parts dag maand jaar value|
	value := (aValue trimBoth select: [:char | '1234567890.-/ ' includes: char]).
	value size < 3 ifTrue: [^'Not enough digits for a date'].
	value size > 10 ifTrue: [^'Too many digits for a date'].
	parts := value findTokens: '.-/ '.
	(parts size = 1) ifTrue: [
		value := parts first.
		(value size ~= 4 and: [ value size ~= 6 ] and: [value size ~= 8 ]) 
			ifTrue:[^'A date should consist of 4, 6 or 8 digits'].
		dag := (value copyFrom: 1 to: 2) asInteger.
		maand := (value copyFrom: 3 to: 4) asInteger.
		value size > 4
			ifTrue: [ jaar := (value copyFrom: 5 to: value size) asInteger ]
			ifFalse: [ jaar := 0 ]	]
	 ifFalse: [
		(parts size > 3) ifTrue: [^'Too many parts'].
		dag := parts first asInteger.
		maand := parts second asInteger.
		(parts size = 2)
			ifTrue: [ jaar := 0 ]
			ifFalse: [ jaar := parts third asInteger ] ].
	dag > 31 ifTrue: [^'Day should be lower than 32 '].
	maand > 12 ifTrue: [^'Month should be lower than 13 '].
	jaar >= 2100 ifTrue: [^'Years untill 2100'].
	((jaar < 1900) and: [jaar>100]) ifTrue: [^'Years from 1900'].
	^''! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
format: aValue
"4 tot 8 cijfers, eventeel gescheiden. return aValue als niet valid, early out"
	|parts dag maand jaar value|
	value := (aValue trimBoth select: [:char | '1234567890.-/ ' includes: char]).
	value size < 3 ifTrue: [^aValue].
	value size > 10 ifTrue: [^aValue].
	parts := value findTokens: '.-/ '.
	parts size = 1
		ifTrue: [
			value := parts first.
			(value size ~= 4 and: [ value size ~= 6 ] and: [value size ~= 8 ]) ifTrue:[^aValue].
			dag := (value copyFrom: 1 to: 2) asInteger.
			maand := (value copyFrom: 3 to: 4) asInteger.
			value size = 4
				ifTrue: [
					jaar := Date today year.
					futureDate 
						ifTrue: [ (Date year: jaar month: maand day: dag) < Date today 
							ifTrue: [ jaar := jaar + 1 ] ]
						ifFalse: [ (Date year: jaar month: maand day: dag) > Date today 
							ifTrue: [ jaar := jaar - 1 ] ] ]
				ifFalse: [
					jaar := (value copyFrom: 5 to: value size) asInteger.
					jaar < 100 ifTrue: [ jaar := jaar + 2000 ] ] ]
		ifFalse: [
			parts size > 3 ifTrue: [^aValue].
			dag := parts first asInteger.
			maand := parts second asInteger.
			parts size = 2
				ifTrue: [
					jaar := Date today year.
					futureDate 
						ifTrue: [ (Date year: jaar month: maand day: dag) < Date today 
							ifTrue: [ jaar := jaar + 1 ] ]
						ifFalse: [ (Date year: jaar month: maand day: dag) > Date today 
							ifTrue: [ jaar := jaar - 1 ] ] ]
				ifFalse: [
					jaar := parts third asInteger ] ].
	dag > 31 ifTrue: [^aValue].
	maand > 12 ifTrue: [^aValue].
	jaar >= 2100 ifTrue: [^aValue].
	((jaar < 1900) and: [jaar>100]) ifTrue: [^aValue].
	^(dag asString padded: #left to: 2 with: $0),'-',(maand asString padded: #left to: 2 with: $0),'-', jaar asString
	
! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
fullUpdate
	^true! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
futureDate
	^ futureDate! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
futureDate: anObject
	futureDate := anObject! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
isValid: aValue
"4 tot 8 cijfers, eventeel gescheiden. return false als niet valid, early out"
	|parts dag maand jaar value|
	(aValue isKindOf: Date) ifTrue: [ ^true ].
	(aValue isKindOf: Timespan) ifTrue: [ ^true ].
	self required
		ifFalse: [ 
			aValue ifNil: [ ^true ].
			aValue ifEmpty: [ ^true ] ].			
	value := (aValue trimBoth select: [:char | '1234567890.-/ ' includes: char]).
	value size < 3 ifTrue: [^false].
	value size > 10 ifTrue: [^false].
	parts := value findTokens: '.-/ '.
	parts size = 1 
		ifTrue: [
			value := parts first.
			(value size ~= 4 and: [ value size ~= 6 ] and: [value size ~= 8 ]) ifTrue:[^false].
			dag := (value copyFrom: 1 to: 2) asInteger.
			maand := (value copyFrom: 3 to: 4) asInteger.
			value size = 4
				ifTrue: [ jaar := 0 ]
				ifFalse: [ jaar := (value copyFrom: 5 to: value size) asInteger ] ]
		ifFalse: [
			parts size > 3 ifTrue: [^false].
			dag := parts first asInteger.
			maand := parts second asInteger.
			parts size = 2
				ifTrue: [ jaar := 0 ]
				ifFalse: [ jaar := parts third asInteger ] ].
	dag > 31 ifTrue: [^false].
	maand > 12 ifTrue: [^false].
	jaar >= 2100 ifTrue: [^false].
	((jaar < 1900) and: [jaar>100]) ifTrue: [^false].
	self required ifTrue: [ ^value notEmpty ].
	^true
	
! !

!DEDateValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 15:23'!
stringValueFor: aDate
	aDate ifNotNil: [ ^aDate yyyymmdd ].
	^''! !

DEValidator subclass: #DENumberValidator
	instanceVariableNames: 'errorMessage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Validation'!

!DENumberValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
errorMessage
	^ errorMessage! !

!DENumberValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
errorMessage: anObject 
	errorMessage := anObject! !

!DENumberValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
errorMessageFor: aValue
	(self isValid: aValue)
		ifFalse: [ ^self errorMessage ].
	^ ''! !

!DENumberValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
format: aValue
	^aValue select: [ :each | each isDigit ]! !

!DENumberValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
fullUpdate
	^true! !

!DENumberValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
isValid: aValue
	self required ifTrue: [ ^aValue notEmpty ].
	^super isValid: aValue! !

DEValidator subclass: #DEStringValidator
	instanceVariableNames: 'errorMessage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deltawerken-Core-Validation'!

!DEStringValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
errorMessage
	^ errorMessage! !

!DEStringValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
errorMessage: anObject 
	errorMessage := anObject! !

!DEStringValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
errorMessageFor: aValue
	(self isValid: aValue)
		ifFalse: [ ^self errorMessage ].
	^ ''! !

!DEStringValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:53'!
isValid: aValue
	aValue ifNil: [ ^self required not ].
	self required ifTrue: [ ^aValue notEmpty ].
	^super isValid: aValue! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
adaptedValue: aValue
	^self format: aValue! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
beOptional
	required := false! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
beRequired
	required := true! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
errorMessageFor: aValue
	^self subclassResponsibility! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
errorMessageFor: aValue subject: aSubject
	^self errorMessageFor: aValue! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
format: aValue
	^aValue! !

!DEValidator methodsFor: 'accessing' stamp: 'DiegoLont 5/19/2011 11:13'!
fullUpdate
	" Needs to return true if formatting is done "
	^false! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
inValidate
	validated := false! !

!DEValidator methodsFor: 'accessing' stamp: 'DiegoLont 5/19/2011 11:12'!
info
	^nil! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
isValid: aValue
	^true! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
isValid: aValue subject: aSubject
	^self isValid: aValue! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
isValidError: aValue subject: aSubject
	(self validated and: [ (self isValid: aValue subject: aSubject) not ])
		ifTrue: [ ^self errorMessageFor: aValue subject: aSubject ] 
		ifFalse: [ ^'' ]! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
required
	required ifNil: [ ^false ].
	^required! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
required: aBoolean
	required := aBoolean! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
validate
	validated := true! !

!DEValidator methodsFor: 'accessing' stamp: 'StephanEggermont 5/2/2011 14:51'!
validated
	^ validated ifNil: [ validated := false ]! !
